<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <location filename="../src/AboutView.cpp" line="21"/>
        <source>There&apos;s life outside the browser!</source>
        <translation>¡Hay vida fuera del navegador!</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="22"/>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="25"/>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo lleva mucho tiempo.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="26"/>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor, considere &lt;a href=&apos;%1&apos;&gt;donar&lt;/a&gt; para apoyar el desarrollo de %2.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="29"/>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Informe sobre errores y envíe sus ideas a %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="33"/>
        <source>Icon designed by %1.</source>
        <translation>Icono diseñado por %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="34"/>
        <source>Compact mode contributed by %1.</source>
        <translation>Modo compacto aportado por %1.</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="35"/>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>Soporte de proxy HTTP aportado por %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="38"/>
        <source>Translated by %1</source>
        <translation>Traducido por %1</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="66"/>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Publicado bajo la &lt;a href=&apos;%1&apos;&gt;Licencia Pública General GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/AboutView.cpp" line="78"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="18"/>
        <source>About</source>
        <translation>Acerca de...</translation>
    </message>
    <message>
        <location filename="../src/AboutView.h" line="20"/>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Lo que siempre quiso saber sobre el %1 y nunca se atrevió a preguntar</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="56"/>
        <source>Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <location filename="../src/downloaditem.cpp" line="295"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="298"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="301"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="317"/>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="320"/>
        <source>KB/sec</source>
        <translation>KB/sec</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="323"/>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="329"/>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="332"/>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <location filename="../src/downloaditem.cpp" line="335"/>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <location filename="../src/downloadmanager.cpp" line="47"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta es sólo la versión demo de %1.</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="49"/>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>Sólo se pueden descargar vídeos más cortos de %1 minutos, así puede probar la funcionalidad de descarga.</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="53"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/downloadmanager.cpp" line="54"/>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/downloadmanager.cpp" line="126"/>
        <source>%n Download(s)</source>
        <translation><numerusform>%n Descarga(s)</numerusform><numerusform>%n Descarga(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <location filename="../src/downloadsettings.cpp" line="14"/>
        <source>Change location...</source>
        <translation>Cambiar ubicación...</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="38"/>
        <source>Choose the download location</source>
        <translation>Eligir la ubicación de descarga</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="49"/>
        <source>Download location changed.</source>
        <translation>Ubicación de descarga cambiada.</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="51"/>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Las descargan actuales irán a parar a la anterior ubicación.</translation>
    </message>
    <message>
        <location filename="../src/downloadsettings.cpp" line="63"/>
        <source>Downloading to: %1</source>
        <translation>Descargado: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <location filename="../src/downloadview.cpp" line="18"/>
        <location filename="../src/downloadview.h" line="22"/>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="16"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="17"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="18"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="19"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="20"/>
        <source>Stop playing after current track</source>
        <translation>Parar reproducción después esta pista</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="21"/>
        <source>Next track</source>
        <translation>Siguiente pista</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="22"/>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="23"/>
        <source>Increase volume</source>
        <translation>Subir volumen</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="24"/>
        <source>Decrease volume</source>
        <translation>Bajar volumen</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="25"/>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="26"/>
        <source>Seek forward</source>
        <translation>Buscar adelante</translation>
    </message>
    <message>
        <location filename="../src/globalshortcuts.cpp" line="27"/>
        <source>Seek backward</source>
        <translation>Buscar atrás</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../src/ListModel.cpp" line="47"/>
        <source>Searching...</source>
        <translation>Buscando...</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="48"/>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="49"/>
        <source>No videos</source>
        <translation>No hay vídeos</translation>
    </message>
    <message>
        <location filename="../src/ListModel.cpp" line="50"/>
        <source>No more videos</source>
        <translation>No hay más vídeos</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <location filename="../src/loadingwidget.cpp" line="71"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/MainWindow.cpp" line="105"/>
        <source>&amp;Stop</source>
        <translation>&amp;Parar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="106"/>
        <source>Stop playback and go back to the search view</source>
        <translation>Parar reproducción y volver a la vista de búsqueda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="112"/>
        <source>S&amp;kip</source>
        <translation>Sa&amp;ltar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="113"/>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente vídeo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="119"/>
        <location filename="../src/MainWindow.cpp" line="644"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="120"/>
        <location filename="../src/MainWindow.cpp" line="645"/>
        <source>Pause playback</source>
        <translation>Pausar reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="126"/>
        <location filename="../src/MainWindow.cpp" line="728"/>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="127"/>
        <source>Go full screen</source>
        <translation>Ir a pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="136"/>
        <source>&amp;Compact mode</source>
        <translation>&amp;Modo compacto</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="137"/>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de herramientas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="145"/>
        <source>Open the &amp;YouTube page</source>
        <translation>Abir en la pagina de YouTube</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="146"/>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir a la página del vídeo en YouTube y pausar la reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="152"/>
        <source>Copy the YouTube &amp;link</source>
        <translation>Copiar enlace del vídeo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="153"/>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar al portapapeles el enlace del vídeo de YouTube actual </translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="159"/>
        <source>Copy the video stream &amp;URL</source>
        <translation>Copiar la &amp;URL del stream de vídeo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="160"/>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar al portapapeles la &amp;URL del stream de vídeo actual</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="166"/>
        <source>&amp;Remove</source>
        <translation>Elimina&amp;r</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="167"/>
        <source>Remove the selected videos from the playlist</source>
        <translation>Eliminar los vídeos seleccionados de la lista de reproducción </translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="173"/>
        <source>Move &amp;Up</source>
        <translation>S&amp;ubir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="174"/>
        <source>Move up the selected videos in the playlist</source>
        <translation>Subir en la lista de reproducción los vídeos seleccionados</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="180"/>
        <source>Move &amp;Down</source>
        <translation>&amp;Bajar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="181"/>
        <source>Move down the selected videos in the playlist</source>
        <translation>Bajar en la lista de reproducción los vídeos seleccionados</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="187"/>
        <source>&amp;Clear recent searches</source>
        <translation>&amp;Limpiar las búsquedas recientes</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="192"/>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpiar el historial de búsquedas. Esta acción no puede deshacerse.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="197"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="199"/>
        <source>Ctrl+Q</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="200"/>
        <source>Bye</source>
        <translation>Adiós</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="204"/>
        <source>&amp;Website</source>
        <translation>Sitio &amp;Web</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="206"/>
        <source>%1 on the Web</source>
        <translation>%1 en la Web</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="210"/>
        <source>Make a &amp;donation</source>
        <translation>Haz una &amp;donación</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="211"/>
        <source>Please support the continued development of %1</source>
        <translation>Por favor, apoye el continuo desarrollo de %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="217"/>
        <source>Info about %1</source>
        <translation>Información sobre %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="225"/>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="244"/>
        <source>Mute volume</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="246"/>
        <source>Ctrl+M</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="277"/>
        <location filename="../src/MainWindow.cpp" line="959"/>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="278"/>
        <source>Show details about video downloads</source>
        <translation>Muestra detalles sobre las descargas de vídeos</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="286"/>
        <source>&amp;Download</source>
        <translation>&amp;Descargar</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="287"/>
        <source>Download the current video</source>
        <translation>Descarga el vídeo actual</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="328"/>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="336"/>
        <source>&amp;Playlist</source>
        <translation>Lista de Re&amp;producción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="343"/>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="362"/>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="439"/>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presiona %1 para subir el volumen, %2 para bajarlo</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="578"/>
        <location filename="../src/MainWindow.cpp" line="584"/>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="597"/>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>¿Deseas salir de %1 con una descarga activa?</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="598"/>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Si cierras %1, esta descarga se cancelará.</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="601"/>
        <source>Close and cancel download</source>
        <translation>Cerrar y cancelar la descarga</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="602"/>
        <source>Wait for download to finish</source>
        <translation>Esperar la finalización de la descarga</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="635"/>
        <source>Fatal error: %1</source>
        <translation>Error fatal: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="637"/>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="660"/>
        <source>&amp;Play</source>
        <translation>Re&amp;producir</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="661"/>
        <source>Resume playback</source>
        <translation>Reiniciar la reproducción</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="751"/>
        <source>Exit &amp;Full Screen</source>
        <translation>Salir de pantalla &amp;completa</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="834"/>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="892"/>
        <source>Volume at %1%</source>
        <translation>Volumen al %1%</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="898"/>
        <source>Volume is muted</source>
        <translation>El volumen está desactivado</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="901"/>
        <source>Volume is unmuted</source>
        <translation>El volumen está activado</translation>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="908"/>
        <source>Maximum video definition set to %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="944"/>
        <source>Your privacy is now safe</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MainWindow.cpp" line="960"/>
        <source>Downloads complete</source>
        <translation>Descargas completadas</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <location filename="../src/MediaView.cpp" line="33"/>
        <source>Most relevant</source>
        <translation>Más relevantes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="40"/>
        <source>Most recent</source>
        <translation>Más recientes</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="47"/>
        <source>Most viewed</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="489"/>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ahora puedes pegar el enlace de Youtube en otra aplicación</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="497"/>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Ahora puedes pegar la URL del stream de vídeo en otra aplicación</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="498"/>
        <source>The link will be valid only for a limited time.</source>
        <translation>EL enlace será válido sólo por un plazo de tiempo limitado.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="594"/>
        <source>This is just the demo version of %1.</source>
        <translation>Esta es sólo la versión de demo de %1.</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="595"/>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="598"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="599"/>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
    <message>
        <location filename="../src/MediaView.cpp" line="625"/>
        <source>Downloading %1</source>
        <translation>Descargand %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <location filename="../src/networkaccess.cpp" line="258"/>
        <source>Network error: %1</source>
        <translation>Error de red: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
        <source>%1 views</source>
        <translation>%1 vistas</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) -- %4</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
        <source>Failed</source>
        <translation>Falló</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
        <source>Completed</source>
        <translation>Completo</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
        <source>Stopped</source>
        <translation>Parado</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
        <source>Stop downloading</source>
        <translation>Parar descarga</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
        <source>Show in %1</source>
        <translation>Mostrar en %1</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
        <source>Open parent folder</source>
        <translation>Abrir carpeta padre</translation>
    </message>
    <message>
        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
        <source>Restart downloading</source>
        <translation>Reiniciar descarga</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <location filename="../src/searchlineedit.cpp" line="177"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../src/SearchView.cpp" line="74"/>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido/a a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="41"/>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="88"/>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>Introducir</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="93"/>
        <source>a keyword</source>
        <translation>una palabra clave</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="94"/>
        <source>a channel</source>
        <translation>un canal</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="99"/>
        <source>to start watching videos.</source>
        <translation>empezar a ver vídeos</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="124"/>
        <source>Watch</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="141"/>
        <source>Recent keywords</source>
        <translation>Palabras clave recientes</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="159"/>
        <source>Recent channels</source>
        <translation>Canales recientes</translation>
    </message>
    <message>
        <location filename="../src/SearchView.cpp" line="358"/>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/SearchView.h" line="35"/>
        <source>Make yourself comfortable</source>
        <translation>Siéntete como en casa</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <location filename="../src/video.cpp" line="186"/>
        <source>Cannot get video stream for %1</source>
        <translation/>
    </message>
    <message>
        <location filename="../src/video.cpp" line="204"/>
        <source>Network error: %1 for %2</source>
        <translation/>
    </message>
</context>
</TS>